@@ -9,6 +9,8 @@ if(is.null(n))
     stop("lambda must be specified")
   if(n<=0 | round(n)!=n)
     stop("sample size must be a positive integer")      
+  if(sigma<=0)
+    stop("sigma must be positive")
 v=runif(n)
 u=runif(n)
 sigma*(qnorm(1+pnorm(lambda)*(v-1))+lambda)
